@@ -1,6 +1,5 @@
-/**
- * Copyright (C) 2009, Progress Software Corporation and/or its 
- * subsidiaries or affiliates.  All rights reserved.
+/*
+ * Copyright (C) 2009-2017 the original author(s).
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -226,7 +225,15 @@ public class Kernel32 {
         public short height() {
             return (short) (bottom-top);
         }
-    }    
+        public SMALL_RECT copy() {
+            SMALL_RECT rc = new SMALL_RECT();
+            rc.left = left;
+            rc.top = top;
+            rc.right = right;
+            rc.bottom = bottom;
+            return rc;
+        }
+    }
 
     /**
      * see http://msdn.microsoft.com/en-us/library/ms686047%28VS.85%29.aspx
